@@ -25,19 +25,6 @@ format_str = """
 --------------------------------------
 """
 
-def fromisoformat(date_string: str):
-    dt = datetime.datetime.fromisoformat(date_string).replace(microsecond=0)
-    if not dt.tzinfo:
-        now = datetime.datetime.now().astimezone()
-        dt = dt.replace(tzinfo=now.tzinfo)
-    return dt
-
-import datetime
-
-now = datetime.datetime.now().astimezone()
-then = datetime.datetime.fromisoformat("2022-10-07T22:15:00")
-than = then.replace(tzinfo=now.tzinfo)
-
 def parse_args(ctl_args):
     parser = argparse.ArgumentParser()
     parser.add_argument("device_mac", nargs='?', help="Aranet4 Bluetooth Address")
@@ -56,14 +43,14 @@ def parse_args(ctl_args):
         "-s",
         "--start",
         metavar="DATE",
-        type=fromisoformat,
+        type=datetime.datetime.fromisoformat,
         help="Records range start (UTC time, example: 2019-09-29T14:00:00",
     )
     history.add_argument(
         "-e",
         "--end",
         metavar="DATE",
-        type=fromisoformat,
+        type=datetime.datetime.fromisoformat,
         help="Records range end (UTC time, example: 2019-09-30T14:00:00",
     )
     history.add_argument(
@@ -137,7 +124,7 @@ def print_records(records):
         print(" pressure |", end="")
     print("")
     print("-" * char_repeat)
-    filtered_values = records.value[records.filter.begin - 1 : records.filter.end]
+    filtered_values = records.value
     for record_id, line in enumerate(filtered_values, start=records.filter.begin):
         print(f"{record_id:>4d} | {line.date.isoformat()} |", end="")
         if records.filter.incl_co2:
@@ -244,7 +231,7 @@ def main(argv):
     if args.records:
         if args.wait:
             wait_for_new_record(args.device_mac)
-        records = client.get_all_records(args.device_mac, vars(args))
+        records = client.get_all_records(args.device_mac, vars(args), True)
         print_records(records)
         if args.output:
             write_csv(args.output, records)
