@@ -460,6 +460,13 @@ def _log_times(now, total, interval, ago):
     return times
 
 
+def _attach_tzinfo(dt: datetime) -> datetime:
+    if dt and not dt.tzinfo:
+        now = datetime.datetime.now().astimezone()
+        dt = dt.replace(tzinfo=now.tzinfo)
+    return dt
+
+
 def _calc_start_end(datapoint_times: int, entry_filter):
     """
     Apply filters to get required start and end datapoint.
@@ -469,8 +476,8 @@ def _calc_start_end(datapoint_times: int, entry_filter):
         `end`: datetime : Get entries before specified time
     """
     last_n_entries = entry_filter.get("last")
-    filter_start = entry_filter.get("start")
-    filter_end = entry_filter.get("end")
+    filter_start = _attach_tzinfo(entry_filter.get("start"))
+    filter_end = _attach_tzinfo(entry_filter.get("end"))
     start = 0x0001
     end = len(datapoint_times)
     if last_n_entries:
@@ -581,7 +588,7 @@ def find_nearby(detect_callback: callable, duration: int = 5) -> List[BLEDevice]
 
     return asyncio.run(_find_nearby(detect_callback, duration))
 
-async def _all_records(address, entry_filter):
+async def _all_records(address, entry_filter, remove_empty):
     """
     Get stored data points from device. Apply any filters requested
     `entry_filter` is a dictionary that can have the following values:
@@ -659,10 +666,12 @@ async def _all_records(address, entry_filter):
     record = Record(dev_name, dev_version, log_size, rec_filter)
     for date, co2, temp, pres, hum in data:
         record.value.append(RecordItem(date, temp, hum, pres, co2))
+    if (remove_empty):
+        record.value = record.value[begin-1:end+1]
     return record
 
 
-def get_all_records(mac_address: str, entry_filter: dict) -> Record:
+def get_all_records(mac_address: str, entry_filter: dict, remove_empty: bool = False) -> Record:
     """
     Get stored datapoints from device. Apply any filters requested
     `entry_filter` is a dictionary that can have the following values:
@@ -674,4 +683,4 @@ def get_all_records(mac_address: str, entry_filter: dict) -> Record:
         `pres`: bool : Get pressure data points (default = True)
         `co2`: bool : Get co2 data points (default = True)
     """
-    return asyncio.run(_all_records(mac_address, entry_filter))
+    return asyncio.run(_all_records(mac_address, entry_filter, remove_empty))
